@@ -3,7 +3,7 @@ import numpy as np
 import copy
 
 class image_dehazer():
-    def __init__(self, airlightEstimation_windowSze=15, boundaryConstraint_windowSze=3, C0=20, C1=300, regularize_lambda=0.1, sigma=0.5, delta=0.85):
+    def __init__(self, airlightEstimation_windowSze=15, boundaryConstraint_windowSze=3, C0=20, C1=300, regularize_lambda=0.1, sigma=0.5, delta=0.85, showHazeTrasmissionMap=True):
         self.airlightEstimation_windowSze = airlightEstimation_windowSze
         self.boundaryConstraint_windowSze = boundaryConstraint_windowSze
         self.C0 = C0
@@ -11,7 +11,7 @@ class image_dehazer():
         self.regularize_lambda = regularize_lambda
         self.sigma = sigma
         self.delta = delta
-
+        self.showHazeTrasmissionMap=showHazeTrasmissionMap
         self._A = []
         self._transmission = []
         self._WFun = []
@@ -137,10 +137,10 @@ class image_dehazer():
 
             self._Transmission = np.abs(np.fft.ifft2((gamma * tF + DU) / (gamma + DS)))
             beta = beta * beta_rate
-
-        cv2.imshow("a", self._Transmission)
-        cv2.waitKey(0)
-        print('here')
+        
+        if(self.showHazeTrasmissionMap):
+            cv2.imshow("Haze Transmission Map", self._Transmission)
+            cv2.waitKey(1)
 
     def __removeHaze(self, HazeImg):
         '''
@@ -288,9 +288,9 @@ class image_dehazer():
         haze_corrected_img = self.__removeHaze(HazeImg)
         return (haze_corrected_img)
 
-def remove_haze(HazeImg, airlightEstimation_windowSze=15, boundaryConstraint_windowSze=3, C0=20, C1=300, regularize_lambda=0.1, sigma=0.5, delta=0.85):
+def remove_haze(HazeImg, airlightEstimation_windowSze=15, boundaryConstraint_windowSze=3, C0=20, C1=300, regularize_lambda=0.1, sigma=0.5, delta=0.85, showHazeTrasmissionMap=True):
     Dehazer = image_dehazer(airlightEstimation_windowSze=airlightEstimation_windowSze,
                             boundaryConstraint_windowSze=boundaryConstraint_windowSze, C0=C0, C1=C1,
-                            regularize_lambda=regularize_lambda, sigma=sigma, delta=delta)
+                            regularize_lambda=regularize_lambda, sigma=sigma, delta=delta, showHazeTrasmissionMap=showHazeTrasmissionMap)
     HazeCorrectedImg = Dehazer.remove_haze(HazeImg)
     return(HazeCorrectedImg)
\ No newline at end of file
